@@ -1,24 +1,14 @@
 /*
-    Copyright (C) 2018 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2018 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <config-kitinerary.h>
 
 #include <KItinerary/ExtractorEngine>
 #include <KItinerary/ExtractorPostprocessor>
+#include <KItinerary/ExtractorValidator>
 #include <KItinerary/HtmlDocument>
 #include <KItinerary/JsonLdDocument>
 #include <KItinerary/PdfDocument>
@@ -135,8 +125,16 @@ private Q_SLOTS:
         const auto result = JsonLdDocument::fromJson(jsonResult);
         ExtractorPostprocessor postproc;
         postproc.setContextDate(contextMsg.date()->dateTime());
+        postproc.setValidationEnabled(false);
         postproc.process(result);
-        const auto postProcResult = JsonLdDocument::toJson(postproc.result());
+        auto postProcResult = postproc.result();
+
+        ExtractorValidator validator;
+        validator.setAcceptOnlyCompleteElements(false);
+        postProcResult.erase(std::remove_if(postProcResult.begin(), postProcResult.end(), [&validator](const auto &elem) {
+            return !validator.isValidElement(elem);
+        }), postProcResult.end());
+
         if (postProcResult.isEmpty() && expectedSkip) {
             QSKIP("result filtered");
             return;
@@ -147,21 +145,24 @@ private Q_SLOTS:
         }
         QVERIFY(!postProcResult.isEmpty());
 
+        const auto encodedResult = JsonLdDocument::toJson(postProcResult);
+        QCOMPARE(encodedResult.size(), postProcResult.size());
+
         const QString refFile = inputFile + QLatin1String(".json");
         if (!QFile::exists(refFile) && !expectedSkip) {
             QFile f(refFile);
             QVERIFY(f.open(QFile::WriteOnly));
-            f.write(QJsonDocument(postProcResult).toJson());
+            f.write(QJsonDocument(encodedResult).toJson());
             return;
         }
 
         QFile f(refFile);
         QVERIFY(f.open(QFile::ReadOnly));
         const auto refDoc = QJsonDocument::fromJson(f.readAll());
-        if (refDoc.array() != postProcResult) {
+        if (refDoc.array() != encodedResult) {
             QFile failFile(refFile + QLatin1String(".fail"));
             QVERIFY(failFile.open(QFile::WriteOnly));
-            failFile.write(QJsonDocument(postProcResult).toJson());
+            failFile.write(QJsonDocument(encodedResult).toJson());
             failFile.close();
 
             QProcess proc;
@@ -170,7 +171,7 @@ private Q_SLOTS:
             QVERIFY(proc.waitForFinished());
         }
 
-        QCOMPARE(refDoc.array(), postProcResult);
+        QCOMPARE(refDoc.array(), encodedResult);
     }
 
     void testNegative()
